from textual.app import App

from kaskade.body import Data
from kaskade.footer import Footer
from kaskade.header import Header
from kaskade.kafka import Kafka
from kaskade.kaskade import kaskade
from kaskade.sidebar import Topics


class Tui(App):
    def __init__(
        self,
        console=None,
        screen=True,
        driver_class=None,
        log="",
        log_verbosity=1,
        config=None,
    ):
        super().__init__(
            console=console,
            screen=screen,
            driver_class=driver_class,
            log=log,
            log_verbosity=log_verbosity,
            title=kaskade.name,
        )
        self.config = config
        self.kafka = Kafka(self.config.kafka)

    async def on_mount(self):
        await self.view.dock(Header(), edge="top")
        await self.view.dock(Footer(), edge="bottom")
        await self.view.dock(Topics(self.kafka), edge="left", size=50)
        await self.view.dock(Data(), edge="right")

    async def on_load(self, event):
        await self.bind("q", "quit")



import sys

from rich.console import Console

from kaskade.config import Config
from kaskade.kaskade import Kaskade
from kaskade.tui import Tui


class Cli:
    def __init__(self, print_version=False, config_file=None):
        self.print_version = print_version
        self.config_file = config_file

    def run(self):
        try:
            self.option_version()
            self.run_tui()
        except Exception as ex:
            console = Console()
            console.print(
                ":thinking_face: [bold red]A problem has occurred[/]: {}".format(
                    str(ex)
                )
            )

    def run_tui(self):
        Tui.run(config=Config(self.config_file))

    def option_version(self):
        if self.print_version:
            kaskade = Kaskade()
            console = Console()
            console.print(kaskade.riched_name())
            console.print(kaskade.riched_version())
            sys.exit(0)



import click

from kaskade.cli import Cli


@click.command()
@click.option("--version", is_flag=True, help="Show the app version.")
@click.argument("config_file", metavar="<config file>", nargs=1, required=False)
def main(version, config_file):
    """

    kaskade is a terminal user interface for kafka.

    \b
    It receives an argument <config file>, in case of not passing
    any argument it'll take any of next config file names by default:
    kaskade.yml, kaskade.yaml, config.yml, config.yaml.

    \b
    Examples:
        kaskade
        kaskade config.yml
    """
    cli = Cli(print_version=version, config_file=config_file)
    cli.run()


if __name__ == "__main__":
    main()



from textual.widget import Widget

from kaskade.kaskade import kaskade


class Header(Widget):
    name = "Header"

    def __init__(self):
        super().__init__(name=self.name)
        self.layout_size = 6

    def render(self):
        return kaskade.riched_name()



from rich import box
from rich.panel import Panel
from textual.reactive import Reactive
from textual.widget import Widget


class Data(Widget):
    mouse_over = Reactive(False)
    has_focus = Reactive(False)
    name = "Data"

    def __init__(self):
        super().__init__(name=self.name)

    def render(self):
        return Panel(
            "Hello World!",
            title=self.name,
            border_style=self.border_style(),
            box=box.SQUARE,
            title_align="left",
        )

    def border_style(self):
        return "green" if self.mouse_over or self.has_focus else "grey93"

    async def on_enter(self):
        self.mouse_over = True

    async def on_leave(self):
        self.mouse_over = False

    async def on_focus(self, event):
        self.has_focus = True

    async def on_blur(self, event):
        self.has_focus = False



from confluent_kafka.admin import AdminClient


class Kafka:
    def __init__(self, config):
        self.config = config

    def topics(self):
        admin_client = AdminClient(self.config)
        return admin_client.list_topics(timeout=2).topics



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['kaskade']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=5.4.1,<6.0.0',
 'click>=8.0.1,<9.0.0',
 'confluent-kafka>=1.7.0,<2.0.0',
 'pathlib>=1.0.1,<2.0.0',
 'pyfiglet>=0.8.post1,<0.9',
 'rich>=10.9.0,<11.0.0',
 'textual>=0.1.12,<0.2.0']

entry_points = \
{'console_scripts': ['kaskade = kaskade.app:main']}

setup_kwargs = {
    'name': 'kaskade',
    'version': '0.0.0a1',
    'description': 'kaskade is a terminal user interface for kafka',
    'long_description': '<pre style="font-family:Menlo,\'DejaVu Sans Mono\',consolas,\'Courier New\',monospace">\n<span style="color: #800080; text-decoration-color: #800080">╔══════════════════════════════════════╗</span>\n<span style="color: #800080; text-decoration-color: #800080">║</span> <span style="color: #800080; text-decoration-color: #800080"> _             _             _      </span> <span style="color: #800080; text-decoration-color: #800080">║</span>\n<span style="color: #800080; text-decoration-color: #800080">║</span> <span style="color: #800080; text-decoration-color: #800080">| | ____ _ ___| | ____ _  __| | ___ </span> <span style="color: #800080; text-decoration-color: #800080">║</span>\n<span style="color: #800080; text-decoration-color: #800080">║</span> <span style="color: #800080; text-decoration-color: #800080">| |/ / _` / __| |/ / _` |/ _` |/ _ \\</span> <span style="color: #800080; text-decoration-color: #800080">║</span>\n<span style="color: #800080; text-decoration-color: #800080">║</span> <span style="color: #800080; text-decoration-color: #800080">|   &lt; (_| \\__ \\   &lt; (_| | (_| |  __/</span> <span style="color: #800080; text-decoration-color: #800080">║</span>\n<span style="color: #800080; text-decoration-color: #800080">║</span> <span style="color: #800080; text-decoration-color: #800080">|_|\\_\\__,_|___/_|\\_\\__,_|\\__,_|\\___|</span> <span style="color: #800080; text-decoration-color: #800080">║</span>\n<span style="color: #800080; text-decoration-color: #800080">╚══════════════════════════════════════╝</span>\n</pre>\n\n<a href="https://github.com"><img alt="GitHub" src="https://img.shields.io/badge/-github-orange?logo=github&logoColor=white"></a>\n<a href="https://github.com/sauljabin/kaskade"><img alt="GitHub" src="https://img.shields.io/badge/status-wip-orange"></a>\n<a href="https://github.com/sauljabin/kaskade"><img alt="GitHub" src="https://badges.pufler.dev/updated/sauljabin/kaskade?label=updated"></a>\n<a href="https://github.com/sauljabin/kaskade/blob/main/LICENSE"><img alt="MIT License" src="https://img.shields.io/github/license/sauljabin/kaskade"></a>\n<a href="https://github.com/sauljabin/kaskade/actions"><img alt="GitHub Actions" src="https://img.shields.io/github/checks-status/sauljabin/kaskade/main?label=tests"></a>\n<a href="https://app.codecov.io/gh/sauljabin/kaskade"><img alt="Codecov" src="https://img.shields.io/codecov/c/github/sauljabin/kaskade"></a>\n<br>\n<a href="https://www.python.org/"><img alt="Python" src="https://img.shields.io/badge/-python-success?logo=python&logoColor=white"></a>\n<a href="https://pypi.org/project/kaskade"><img alt="Version" src="https://img.shields.io/pypi/v/kaskade"></a>\n<a href="https://pypi.org/project/kaskade"><img alt="Python Versions" src="https://img.shields.io/pypi/pyversions/kaskade"></a>\n<a href="https://libraries.io/pypi/kaskade"><img alt="Dependencies" src="https://img.shields.io/librariesio/release/pypi/kaskade"></a>\n<a href="https://pypi.org/project/kaskade"><img alt="Platform" src="https://img.shields.io/badge/platform-linux%20%7C%20osx-blueviolet"></a>\n<br>\n<a href="https://www.docker.com/"><img alt="Docker" src="https://img.shields.io/badge/-docker-blue?logo=docker&logoColor=white"></a>\n<a href="https://hub.docker.com/r/sauljabin/kaskade"><img alt="Docker Image Version (latest by date)" src="https://img.shields.io/docker/v/sauljabin/kaskade"></a>\n<a href="https://hub.docker.com/r/sauljabin/kaskade"><img alt="Docker Image Size (latest by date)" src="https://img.shields.io/docker/image-size/sauljabin/kaskade"></a>\n<br>\n<a href="https://kafka.apache.org/"><img alt="Kafka" src="https://img.shields.io/badge/-kafka-grey?logo=apache-kafka&logoColor=white"></a>\n<a href="https://kafka.apache.org/"><img alt="Kafka" src="https://img.shields.io/badge/kafka-2.8%20%7C%203.0-blue"/></a>\n\n\n`kaskade` is a terminal user interface for [kafka](https://kafka.apache.org/).\n\n## Installation\n\nInstall with pip:\n```sh\npip install kaskade\n```\n\nUpgrade with pip:\n```sh\npip install --upgrade kaskade\n```\n\n## Usage\n\nHelp:\n```sh\nkaskade --help\n```\n\nVersion:\n```sh\nkaskade --version\n```\n\nRun without config file (it\'ll take any of `kaskade.yml`, `kaskade.yaml`, `config.yml`, `config.yaml`):\n```sh\nkaskade\n```\n\nRun with config file:\n```sh\nkaskade my-file.yml\n```\n\nUsing docker (add a `network` and `volume`):\n```sh\ndocker run --rm -it --network kafka-sandbox_network -v $(pwd)/config.yml:/kaskade/config.yml sauljabin/kaskade:latest\n```\n\n## Development\n\n### Poetry\n\nInstalling poetry:\n```sh\npip install poetry\n```\n\nInstalling development dependencies:\n```sh\npoetry install\n```\n\nBuild (it\'ll create the `dist` folder):\n```sh\npoetry build\n```\n\n### Scripts\n\nRunning unit tests:\n```sh\npoetry run python -m scripts.tests\n```\n\nRunning multi version tests (`3.7`, `3.8`, `3.9`):\n\n> Make sure you have `python3.7`, `python3.8`, `python3.9` aliases installed\n\n```sh\npoetry run python -m scripts.multi-version-tests\n```\n\nApplying code styles:\n```sh\npoetry run python -m scripts.styles\n```\n\nRunning code analysis:\n```sh\npoetry run python -m scripts.analyze\n```\n\nRunning code coverage:\n```sh\npoetry run python -m scripts.tests-coverage\n```\n\nGenerate readme banner:\n```sh\npoetry run python -m scripts.banner\n```\n\nRunning cli using `poetry`:\n```sh\npoetry run kaskade\n```\n\n### Docker\n\nBuild docker:\n```sh\npoetry build\ndocker build -t sauljabin/kaskade:latest -f ./docker/Dockerfile .\n```\n\nRun with docker:\n```sh\ndocker run --rm -it --network kafka-sandbox_network -v $(pwd)/config.yml:/kaskade/config.yml sauljabin/kaskade:latest\n```',
    'author': 'Saúl Piña',
    'author_email': 'sauljabin@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/sauljabin/kaskade',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from pathlib import Path

import yaml


class Config:
    def __init__(self, path):
        self.path = path
        config_files = ["kaskade.yml", "kaskade.yaml", "config.yml", "config.yaml"]
        if self.path:
            if not Path(self.path).exists():
                raise Exception(f"Config file {path} not found")
        else:
            default_config_file = next(
                iter([path for path in config_files if Path(path).exists()]), None
            )
            self.path = default_config_file
            if not self.path:
                raise Exception(
                    "Default config file kaskade.yml, kaskade.yaml, "
                    "config.yml or config.yaml not found"
                )

        with open(self.path, "r") as file:
            self.text = file.read()
            self.yaml = yaml.safe_load(self.text)
            self.kafka = self.yaml.get("kafka")
            self.kaskade = self.yaml.get("kaskade")



import pkg_resources
from pyfiglet import Figlet
from rich.text import Text


class Kaskade:
    def __init__(self):
        self.name = "kaskade"
        self.version = pkg_resources.get_distribution("kaskade").version
        self.documentation = "https://github.com/sauljabin/kaskade"

    def figleted_name(self):
        figlet = Figlet(font="standard")
        return figlet.renderText(self.name).rstrip()

    def riched_name(self):
        return Text.from_markup("[magenta]{}[/]".format(self.figleted_name()))

    def riched_version(self):
        return Text.from_markup(
            "[magenta]{}[/] [green]v{}[/] [blue]{}[/]".format(
                self.name, self.version, self.documentation
            )
        )


kaskade = Kaskade()
VERSION = kaskade.version
NAME = kaskade.name
DOCUMENTATION = kaskade.documentation
